@@ -1,5 +1,5 @@
 # apt-forktracer - a utility for managing package versions
-# Copyright (C) 2008 Marcin Owsiany <porridge@debian.org>
+# Copyright (C) 2008-2010 Marcin Owsiany <porridge@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ class Facter:
 		if not self.distributors_id:
 			self.distributors_id = self.get_distrib_id_from_command(lsb_release)
 		if not self.distributors_id:
-			self.distributors_id = self.get_distrib_id_from_file('/etc/lsb-release')
+			self.distributors_id = self.get_distrib_id_from_file(file)
 		if not self.distributors_id:
 			raise RuntimeError('Could not obtain distributors id from lsb_release')
 
