@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # apt-forktracer - a utility for managing package versions
-# Copyright (C) 2008 Marcin Owsiany <porridge@debian.org>
+# Copyright (C) 2008,2010 Marcin Owsiany <porridge@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,13 +15,12 @@
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-import pmock
 import unittest
 
 from apt_forktracer.testlib import test_helper
 from apt_forktracer.config_finder import ConfigFinder
 
-class Test_Config_Finder(test_helper.TestCase):
+class Test_Config_Finder(test_helper.MoxTestCase):
 	def test(self):
 		cf = ConfigFinder('test-data/config', 'test-data/not_exists', 'test-data/config.d')
 		entries = 0
